@@ -3,13 +3,14 @@ from typing import Optional, Union
 from nonebot.adapters.onebot.v11 import Bot, Event, Message, MessageSegment, escape
 from nonebot.log import logger
 
-from . import models  # noqa:F401
-
 original_send = Bot.send
 
 
 async def patched_send(
-    self: Bot, event: Event, message: Union[Message, MessageSegment, str], **kwargs
+    self: Bot,
+    event: Event,
+    message: Union[Message, MessageSegment, str],
+    **kwargs,
 ):
     guild_id: Optional[int] = getattr(event, "guild_id", None)
     channel_id: Optional[int] = getattr(event, "channel_id", None)
@@ -26,13 +27,19 @@ async def patched_send(
         escape(message, escape_comma=False) if isinstance(message, str) else message
     )
 
-    message_sent = message if isinstance(message, Message) else Message(message)
+    message_sent = Message()
     if user_id and kwargs.get("at_sender", False):
-        message_sent = MessageSegment.at(user_id) + " " + message_sent
+        message_sent += MessageSegment.at(user_id) + " "
+    message_sent += message
 
     return await self.send_guild_channel_msg(
-        guild_id=guild_id, channel_id=channel_id, message=message_sent
+        guild_id=guild_id,
+        channel_id=channel_id,
+        message=message_sent,
+        **kwargs,
     )
 
 
 Bot.send = patched_send
+
+from .models import *  # noqa
